@@ -5,6 +5,14 @@ from openap import prop
 from openap.extra import ndarrayconvert
 
 
+def func_fuel2(a, b):
+    return lambda x: a * (x + b) ** 2
+
+
+def func_fuel3(c3, c2, c1):
+    return lambda x: c3 * x ** 3 + c2 * x ** 2 + c1 * x
+
+
 class FuelFlow(object):
     """Fuel flow model based on ICAO emission databank."""
 
@@ -16,6 +24,7 @@ class FuelFlow(object):
             eng (string): Engine type (for example: CFM56-5A3).
                 Leave empty to use the default engine specified
                 by in the aircraft database.
+            polydeg (int): Order of the polynomials for fuel flow model (2 or 3), defaults to 2.
 
         """
         if not hasattr(self, "np"):
@@ -27,6 +36,9 @@ class FuelFlow(object):
         if not hasattr(self, "Drag"):
             self.Drag = importlib.import_module("openap.drag").Drag
 
+        if not hasattr(self, "WRAP"):
+            self.WRAP = importlib.import_module("openap.kinematic").WRAP
+
         self.aircraft = prop.aircraft(ac, **kwargs)
 
         if eng is None:
@@ -36,18 +48,25 @@ class FuelFlow(object):
 
         self.thrust = self.Thrust(ac, eng, **kwargs)
         self.drag = self.Drag(ac, **kwargs)
+        self.wrap = self.WRAP(ac, **kwargs)
 
-        c3, c2, c1 = (
-            self.engine["fuel_c3"],
-            self.engine["fuel_c2"],
-            self.engine["fuel_c1"],
-        )
-        # print(c3,c2,c1)
+        polydeg = kwargs.get("polydeg", 2)
 
-        self.func_fuel = prop.func_fuel(c3, c2, c1)
+        if polydeg == 2:
+            a, b = self.engine["fuel_a"], self.engine["fuel_b"]
+            self.polyfuel = func_fuel2(a, b)
+        elif polydeg == 3:
+            c3, c2, c1 = (
+                self.engine["fuel_c3"],
+                self.engine["fuel_c2"],
+                self.engine["fuel_c1"],
+            )
+            self.polyfuel = func_fuel3(c3, c2, c1)
+        else:
+            raise RuntimeError(f"polydeg must be 2 or 3")
 
     @ndarrayconvert
-    def at_thrust(self, acthr, alt=0):
+    def at_thrust(self, acthr, alt=0, limit=True):
         """Compute the fuel flow at a given total thrust.
 
         Args:
@@ -61,9 +80,14 @@ class FuelFlow(object):
         n_eng = self.aircraft["engine"]["number"]
         engthr = acthr / n_eng
 
-        ratio = engthr / self.engine["max_thrust"]
+        maxthr = self.thrust.takeoff(tas=0, alt=0)
+        ratio = acthr / maxthr
 
-        ff_sl = self.func_fuel(ratio)
+        if limit:
+            ratio = self.np.where(ratio < 0.07, 0.07, ratio)
+            ratio = self.np.where(ratio > 1, 1, ratio)
+
+        ff_sl = self.polyfuel(ratio)
         ff_corr_alt = self.engine["fuel_ch"] * (engthr / 1000) * (alt * 0.3048)
         ff_eng = ff_sl + ff_corr_alt
 
@@ -94,7 +118,7 @@ class FuelFlow(object):
         return fuelflow
 
     @ndarrayconvert
-    def enroute(self, mass, tas, alt, path_angle=0):
+    def enroute(self, mass, tas, alt, path_angle=0, limit=True):
         """Compute the fuel flow during climb, cruise, or descent.
 
         The net thrust is first estimated based on the dynamic equation.
@@ -114,17 +138,21 @@ class FuelFlow(object):
         D = self.drag.clean(mass=mass, tas=tas, alt=alt, path_angle=path_angle)
 
         # Convert angles from degrees to radians.
-        gamma = self.np.radians(path_angle)
+        gamma = path_angle * 3.142 / 180
 
-        T = D + mass * 9.80665 * self.np.sin(gamma)
-        T_idle = self.thrust.descent_idle(tas=tas, alt=alt)
-        T = self.np.where(T < 0, T_idle, T)
+        T = D + mass * 9.81 * self.np.sin(gamma)
 
-        fuelflow = self.at_thrust(T, alt)
+        if limit:
+            T_max = self.thrust.climb(tas=tas, alt=alt, roc=0)
+            T_idle = self.thrust.descent_idle(tas=tas, alt=alt)
 
-        # do not return value outside performance boundary, with a margin of 20%
-        T_max = self.thrust.climb(tas=0, alt=alt, roc=0)
-        fuelflow = self.np.where(T > 1.20 * T_max, self.np.nan, fuelflow)
+            # below idle thrust
+            T = self.np.where(T < T_idle, T_idle, T)
+
+            # outside performance boundary (with margin of 20%)
+            T = self.np.where(T > 1.2 * T_max, 1.2 * T_max, T)
+
+        fuelflow = self.at_thrust(T, alt, limit=limit)
 
         return fuelflow
 
@@ -140,10 +168,19 @@ class FuelFlow(object):
         """
         import matplotlib.pyplot as plt
 
+        x = [0.07, 0.3, 0.85, 1.0]
+        y = [
+            self.engine["ff_idl"],
+            self.engine["ff_app"],
+            self.engine["ff_co"],
+            self.engine["ff_to"],
+        ]
+        plt.scatter(x, y, color="k")
+
         xx = self.np.linspace(0, 1, 50)
-        yy = self.func_fuel(xx)
-        # plt.scatter(self.x, self.y, color='k')
+        yy = self.polyfuel(xx)
         plt.plot(xx, yy, "--", color="gray")
+
         if plot:
             plt.show()
         else:
