@@ -11,7 +11,8 @@ dir_aircraft = curr_path + "/data/aircraft/"
 file_engine = curr_path + "/data/engine/engines.csv"
 file_synonym = curr_path + "/data/aircraft/_synonym.csv"
 
-aircraft_synonym = pd.read_csv(file_synonym) 
+aircraft_synonym = pd.read_csv(file_synonym)
+
 
 def available_aircraft(use_synonym=False):
     """Get available aircraft types in OpenAP model.
@@ -30,7 +31,7 @@ def available_aircraft(use_synonym=False):
     return acs
 
 
-def aircraft(ac, use_synonym=False):
+def aircraft(ac, use_synonym=False, **kwargs):
     """Get details of an aircraft type.
 
     Args:
@@ -45,7 +46,7 @@ def aircraft(ac, use_synonym=False):
     files = glob.glob(dir_aircraft + ac + ".yml")
 
     if len(files) == 0:
-        syno = aircraft_synonym.query('orig==@ac')
+        syno = aircraft_synonym.query("orig==@ac")
         if use_synonym and syno.shape[0] > 0:
             new_ac = syno.new.iloc[0]
             files = glob.glob(dir_aircraft + new_ac + ".yml")
@@ -130,9 +131,7 @@ def engine(eng):
         # compute fuel flow correction factor kg/s/N per meter
         if np.isfinite(seleng["cruise_sfc"]):
             sfc_cr = seleng["cruise_sfc"]
-            sfc_to = (seleng["fuel_c3"] + seleng["fuel_c2"] + seleng["fuel_c1"]) / (
-                seleng["max_thrust"] / 1000
-            )
+            sfc_to = seleng["ff_to"] / (seleng["max_thrust"] / 1000)
             fuel_ch = np.round((sfc_cr - sfc_to) / (seleng["cruise_alt"] * 0.3048), 8)
         else:
             fuel_ch = 6.7e-7
@@ -142,7 +141,3 @@ def engine(eng):
         raise RuntimeError(f"Data for engine {eng} not found.")
 
     return seleng
-
-
-def func_fuel(c3, c2, c1):
-    return lambda x: c3 * x ** 3 + c2 * x ** 2 + c1 * x
